# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.31.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class BondMetadata(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'fee': 'str',
        'memo': 'str',
        'node_address': 'str',
        'provider': 'str'
    }

    attribute_map = {
        'fee': 'fee',
        'memo': 'memo',
        'node_address': 'nodeAddress',
        'provider': 'provider'
    }

    def __init__(self, fee=None, memo=None, node_address=None, provider=None):  # noqa: E501
        """BondMetadata - a model defined in Swagger"""  # noqa: E501
        self._fee = None
        self._memo = None
        self._node_address = None
        self._provider = None
        self.discriminator = None
        if fee is not None:
            self.fee = fee
        self.memo = memo
        self.node_address = node_address
        if provider is not None:
            self.provider = provider

    @property
    def fee(self):
        """Gets the fee of this BondMetadata.  # noqa: E501

        node operator fee  # noqa: E501

        :return: The fee of this BondMetadata.  # noqa: E501
        :rtype: str
        """
        return self._fee

    @fee.setter
    def fee(self, fee):
        """Sets the fee of this BondMetadata.

        node operator fee  # noqa: E501

        :param fee: The fee of this BondMetadata.  # noqa: E501
        :type: str
        """

        self._fee = fee

    @property
    def memo(self):
        """Gets the memo of this BondMetadata.  # noqa: E501

        Transaction memo of bond event  # noqa: E501

        :return: The memo of this BondMetadata.  # noqa: E501
        :rtype: str
        """
        return self._memo

    @memo.setter
    def memo(self, memo):
        """Sets the memo of this BondMetadata.

        Transaction memo of bond event  # noqa: E501

        :param memo: The memo of this BondMetadata.  # noqa: E501
        :type: str
        """
        if memo is None:
            raise ValueError("Invalid value for `memo`, must not be `None`")  # noqa: E501

        self._memo = memo

    @property
    def node_address(self):
        """Gets the node_address of this BondMetadata.  # noqa: E501

        node address  # noqa: E501

        :return: The node_address of this BondMetadata.  # noqa: E501
        :rtype: str
        """
        return self._node_address

    @node_address.setter
    def node_address(self, node_address):
        """Sets the node_address of this BondMetadata.

        node address  # noqa: E501

        :param node_address: The node_address of this BondMetadata.  # noqa: E501
        :type: str
        """
        if node_address is None:
            raise ValueError("Invalid value for `node_address`, must not be `None`")  # noqa: E501

        self._node_address = node_address

    @property
    def provider(self):
        """Gets the provider of this BondMetadata.  # noqa: E501

        bond provider address  # noqa: E501

        :return: The provider of this BondMetadata.  # noqa: E501
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """Sets the provider of this BondMetadata.

        bond provider address  # noqa: E501

        :param provider: The provider of this BondMetadata.  # noqa: E501
        :type: str
        """

        self._provider = provider

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BondMetadata, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BondMetadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
