# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.31.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RunePriceMeta(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'end_rune_price_usd': 'str',
        'end_time': 'str',
        'start_rune_price_usd': 'str',
        'start_time': 'str'
    }

    attribute_map = {
        'end_rune_price_usd': 'endRunePriceUSD',
        'end_time': 'endTime',
        'start_rune_price_usd': 'startRunePriceUSD',
        'start_time': 'startTime'
    }

    def __init__(self, end_rune_price_usd=None, end_time=None, start_rune_price_usd=None, start_time=None):  # noqa: E501
        """RunePriceMeta - a model defined in Swagger"""  # noqa: E501
        self._end_rune_price_usd = None
        self._end_time = None
        self._start_rune_price_usd = None
        self._start_time = None
        self.discriminator = None
        self.end_rune_price_usd = end_rune_price_usd
        self.end_time = end_time
        self.start_rune_price_usd = start_rune_price_usd
        self.start_time = start_time

    @property
    def end_rune_price_usd(self):
        """Gets the end_rune_price_usd of this RunePriceMeta.  # noqa: E501

        Int64(e8), The price of Rune based on the USD pools at the end of the interval   # noqa: E501

        :return: The end_rune_price_usd of this RunePriceMeta.  # noqa: E501
        :rtype: str
        """
        return self._end_rune_price_usd

    @end_rune_price_usd.setter
    def end_rune_price_usd(self, end_rune_price_usd):
        """Sets the end_rune_price_usd of this RunePriceMeta.

        Int64(e8), The price of Rune based on the USD pools at the end of the interval   # noqa: E501

        :param end_rune_price_usd: The end_rune_price_usd of this RunePriceMeta.  # noqa: E501
        :type: str
        """
        if end_rune_price_usd is None:
            raise ValueError("Invalid value for `end_rune_price_usd`, must not be `None`")  # noqa: E501

        self._end_rune_price_usd = end_rune_price_usd

    @property
    def end_time(self):
        """Gets the end_time of this RunePriceMeta.  # noqa: E501

        Int64, The end time of bucket in unix timestamp  # noqa: E501

        :return: The end_time of this RunePriceMeta.  # noqa: E501
        :rtype: str
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this RunePriceMeta.

        Int64, The end time of bucket in unix timestamp  # noqa: E501

        :param end_time: The end_time of this RunePriceMeta.  # noqa: E501
        :type: str
        """
        if end_time is None:
            raise ValueError("Invalid value for `end_time`, must not be `None`")  # noqa: E501

        self._end_time = end_time

    @property
    def start_rune_price_usd(self):
        """Gets the start_rune_price_usd of this RunePriceMeta.  # noqa: E501

        Int64(e8), The price of Rune based on the USD pools at the start of the interval   # noqa: E501

        :return: The start_rune_price_usd of this RunePriceMeta.  # noqa: E501
        :rtype: str
        """
        return self._start_rune_price_usd

    @start_rune_price_usd.setter
    def start_rune_price_usd(self, start_rune_price_usd):
        """Sets the start_rune_price_usd of this RunePriceMeta.

        Int64(e8), The price of Rune based on the USD pools at the start of the interval   # noqa: E501

        :param start_rune_price_usd: The start_rune_price_usd of this RunePriceMeta.  # noqa: E501
        :type: str
        """
        if start_rune_price_usd is None:
            raise ValueError("Invalid value for `start_rune_price_usd`, must not be `None`")  # noqa: E501

        self._start_rune_price_usd = start_rune_price_usd

    @property
    def start_time(self):
        """Gets the start_time of this RunePriceMeta.  # noqa: E501

        Int64, The beginning time of bucket in unix timestamp  # noqa: E501

        :return: The start_time of this RunePriceMeta.  # noqa: E501
        :rtype: str
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this RunePriceMeta.

        Int64, The beginning time of bucket in unix timestamp  # noqa: E501

        :param start_time: The start_time of this RunePriceMeta.  # noqa: E501
        :type: str
        """
        if start_time is None:
            raise ValueError("Invalid value for `start_time`, must not be `None`")  # noqa: E501

        self._start_time = start_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RunePriceMeta, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RunePriceMeta):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
