# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.31.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RUNEPoolProvider(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'date_first_added': 'str',
        'date_last_added': 'str',
        'rune_added': 'str',
        'rune_address': 'str',
        'rune_deposit': 'str',
        'rune_withdrawn': 'str',
        'units': 'str'
    }

    attribute_map = {
        'date_first_added': 'dateFirstAdded',
        'date_last_added': 'dateLastAdded',
        'rune_added': 'runeAdded',
        'rune_address': 'runeAddress',
        'rune_deposit': 'runeDeposit',
        'rune_withdrawn': 'runeWithdrawn',
        'units': 'units'
    }

    def __init__(self, date_first_added=None, date_last_added=None, rune_added=None, rune_address=None, rune_deposit=None, rune_withdrawn=None, units=None):  # noqa: E501
        """RUNEPoolProvider - a model defined in Swagger"""  # noqa: E501
        self._date_first_added = None
        self._date_last_added = None
        self._rune_added = None
        self._rune_address = None
        self._rune_deposit = None
        self._rune_withdrawn = None
        self._units = None
        self.discriminator = None
        self.date_first_added = date_first_added
        self.date_last_added = date_last_added
        self.rune_added = rune_added
        self.rune_address = rune_address
        self.rune_deposit = rune_deposit
        self.rune_withdrawn = rune_withdrawn
        self.units = units

    @property
    def date_first_added(self):
        """Gets the date_first_added of this RUNEPoolProvider.  # noqa: E501

        Int64, Unix timestamp for the first time member deposited into the RUNEPool  # noqa: E501

        :return: The date_first_added of this RUNEPoolProvider.  # noqa: E501
        :rtype: str
        """
        return self._date_first_added

    @date_first_added.setter
    def date_first_added(self, date_first_added):
        """Sets the date_first_added of this RUNEPoolProvider.

        Int64, Unix timestamp for the first time member deposited into the RUNEPool  # noqa: E501

        :param date_first_added: The date_first_added of this RUNEPoolProvider.  # noqa: E501
        :type: str
        """
        if date_first_added is None:
            raise ValueError("Invalid value for `date_first_added`, must not be `None`")  # noqa: E501

        self._date_first_added = date_first_added

    @property
    def date_last_added(self):
        """Gets the date_last_added of this RUNEPoolProvider.  # noqa: E501

        Int64, Unix timestamp for the last time member deposited into the RUNEPool  # noqa: E501

        :return: The date_last_added of this RUNEPoolProvider.  # noqa: E501
        :rtype: str
        """
        return self._date_last_added

    @date_last_added.setter
    def date_last_added(self, date_last_added):
        """Sets the date_last_added of this RUNEPoolProvider.

        Int64, Unix timestamp for the last time member deposited into the RUNEPool  # noqa: E501

        :param date_last_added: The date_last_added of this RUNEPoolProvider.  # noqa: E501
        :type: str
        """
        if date_last_added is None:
            raise ValueError("Invalid value for `date_last_added`, must not be `None`")  # noqa: E501

        self._date_last_added = date_last_added

    @property
    def rune_added(self):
        """Gets the rune_added of this RUNEPoolProvider.  # noqa: E501

        Int64(e8), total asset added in the RUNEPool by member  # noqa: E501

        :return: The rune_added of this RUNEPoolProvider.  # noqa: E501
        :rtype: str
        """
        return self._rune_added

    @rune_added.setter
    def rune_added(self, rune_added):
        """Sets the rune_added of this RUNEPoolProvider.

        Int64(e8), total asset added in the RUNEPool by member  # noqa: E501

        :param rune_added: The rune_added of this RUNEPoolProvider.  # noqa: E501
        :type: str
        """
        if rune_added is None:
            raise ValueError("Invalid value for `rune_added`, must not be `None`")  # noqa: E501

        self._rune_added = rune_added

    @property
    def rune_address(self):
        """Gets the rune_address of this RUNEPoolProvider.  # noqa: E501

        address used by the member  # noqa: E501

        :return: The rune_address of this RUNEPoolProvider.  # noqa: E501
        :rtype: str
        """
        return self._rune_address

    @rune_address.setter
    def rune_address(self, rune_address):
        """Sets the rune_address of this RUNEPoolProvider.

        address used by the member  # noqa: E501

        :param rune_address: The rune_address of this RUNEPoolProvider.  # noqa: E501
        :type: str
        """
        if rune_address is None:
            raise ValueError("Invalid value for `rune_address`, must not be `None`")  # noqa: E501

        self._rune_address = rune_address

    @property
    def rune_deposit(self):
        """Gets the rune_deposit of this RUNEPoolProvider.  # noqa: E501

        Int64(e8), total asset that is currently deposited by the member  # noqa: E501

        :return: The rune_deposit of this RUNEPoolProvider.  # noqa: E501
        :rtype: str
        """
        return self._rune_deposit

    @rune_deposit.setter
    def rune_deposit(self, rune_deposit):
        """Sets the rune_deposit of this RUNEPoolProvider.

        Int64(e8), total asset that is currently deposited by the member  # noqa: E501

        :param rune_deposit: The rune_deposit of this RUNEPoolProvider.  # noqa: E501
        :type: str
        """
        if rune_deposit is None:
            raise ValueError("Invalid value for `rune_deposit`, must not be `None`")  # noqa: E501

        self._rune_deposit = rune_deposit

    @property
    def rune_withdrawn(self):
        """Gets the rune_withdrawn of this RUNEPoolProvider.  # noqa: E501

        Int64(e8), total asset withdrawn from the RUNEPool by the member  # noqa: E501

        :return: The rune_withdrawn of this RUNEPoolProvider.  # noqa: E501
        :rtype: str
        """
        return self._rune_withdrawn

    @rune_withdrawn.setter
    def rune_withdrawn(self, rune_withdrawn):
        """Sets the rune_withdrawn of this RUNEPoolProvider.

        Int64(e8), total asset withdrawn from the RUNEPool by the member  # noqa: E501

        :param rune_withdrawn: The rune_withdrawn of this RUNEPoolProvider.  # noqa: E501
        :type: str
        """
        if rune_withdrawn is None:
            raise ValueError("Invalid value for `rune_withdrawn`, must not be `None`")  # noqa: E501

        self._rune_withdrawn = rune_withdrawn

    @property
    def units(self):
        """Gets the units of this RUNEPoolProvider.  # noqa: E501

        Int64, units that belong the the member  # noqa: E501

        :return: The units of this RUNEPoolProvider.  # noqa: E501
        :rtype: str
        """
        return self._units

    @units.setter
    def units(self, units):
        """Sets the units of this RUNEPoolProvider.

        Int64, units that belong the the member  # noqa: E501

        :param units: The units of this RUNEPoolProvider.  # noqa: E501
        :type: str
        """
        if units is None:
            raise ValueError("Invalid value for `units`, must not be `None`")  # noqa: E501

        self._units = units

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RUNEPoolProvider, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RUNEPoolProvider):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
