# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.31.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ReserveItem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'end_time': 'str',
        'gas_fee_outbound': 'str',
        'gas_reimbursement': 'str',
        'network_fee': 'str',
        'start_time': 'str'
    }

    attribute_map = {
        'end_time': 'endTime',
        'gas_fee_outbound': 'gasFeeOutbound',
        'gas_reimbursement': 'gasReimbursement',
        'network_fee': 'networkFee',
        'start_time': 'startTime'
    }

    def __init__(self, end_time=None, gas_fee_outbound=None, gas_reimbursement=None, network_fee=None, start_time=None):  # noqa: E501
        """ReserveItem - a model defined in Swagger"""  # noqa: E501
        self._end_time = None
        self._gas_fee_outbound = None
        self._gas_reimbursement = None
        self._network_fee = None
        self._start_time = None
        self.discriminator = None
        self.end_time = end_time
        self.gas_fee_outbound = gas_fee_outbound
        self.gas_reimbursement = gas_reimbursement
        self.network_fee = network_fee
        self.start_time = start_time

    @property
    def end_time(self):
        """Gets the end_time of this ReserveItem.  # noqa: E501

        Int64, The end time of bucket in unix timestamp  # noqa: E501

        :return: The end_time of this ReserveItem.  # noqa: E501
        :rtype: str
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this ReserveItem.

        Int64, The end time of bucket in unix timestamp  # noqa: E501

        :param end_time: The end_time of this ReserveItem.  # noqa: E501
        :type: str
        """
        if end_time is None:
            raise ValueError("Invalid value for `end_time`, must not be `None`")  # noqa: E501

        self._end_time = end_time

    @property
    def gas_fee_outbound(self):
        """Gets the gas_fee_outbound of this ReserveItem.  # noqa: E501

        Int64(e8), fee made from outbound  # noqa: E501

        :return: The gas_fee_outbound of this ReserveItem.  # noqa: E501
        :rtype: str
        """
        return self._gas_fee_outbound

    @gas_fee_outbound.setter
    def gas_fee_outbound(self, gas_fee_outbound):
        """Sets the gas_fee_outbound of this ReserveItem.

        Int64(e8), fee made from outbound  # noqa: E501

        :param gas_fee_outbound: The gas_fee_outbound of this ReserveItem.  # noqa: E501
        :type: str
        """
        if gas_fee_outbound is None:
            raise ValueError("Invalid value for `gas_fee_outbound`, must not be `None`")  # noqa: E501

        self._gas_fee_outbound = gas_fee_outbound

    @property
    def gas_reimbursement(self):
        """Gets the gas_reimbursement of this ReserveItem.  # noqa: E501

        Int64(e8), RUNE paid to the pool for compensating the gas fees  # noqa: E501

        :return: The gas_reimbursement of this ReserveItem.  # noqa: E501
        :rtype: str
        """
        return self._gas_reimbursement

    @gas_reimbursement.setter
    def gas_reimbursement(self, gas_reimbursement):
        """Sets the gas_reimbursement of this ReserveItem.

        Int64(e8), RUNE paid to the pool for compensating the gas fees  # noqa: E501

        :param gas_reimbursement: The gas_reimbursement of this ReserveItem.  # noqa: E501
        :type: str
        """
        if gas_reimbursement is None:
            raise ValueError("Invalid value for `gas_reimbursement`, must not be `None`")  # noqa: E501

        self._gas_reimbursement = gas_reimbursement

    @property
    def network_fee(self):
        """Gets the network_fee of this ReserveItem.  # noqa: E501

        Int64(e8), RUNE paid to the system on deposit, send messages   # noqa: E501

        :return: The network_fee of this ReserveItem.  # noqa: E501
        :rtype: str
        """
        return self._network_fee

    @network_fee.setter
    def network_fee(self, network_fee):
        """Sets the network_fee of this ReserveItem.

        Int64(e8), RUNE paid to the system on deposit, send messages   # noqa: E501

        :param network_fee: The network_fee of this ReserveItem.  # noqa: E501
        :type: str
        """
        if network_fee is None:
            raise ValueError("Invalid value for `network_fee`, must not be `None`")  # noqa: E501

        self._network_fee = network_fee

    @property
    def start_time(self):
        """Gets the start_time of this ReserveItem.  # noqa: E501

        Int64, The beginning time of bucket in unix timestamp  # noqa: E501

        :return: The start_time of this ReserveItem.  # noqa: E501
        :rtype: str
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this ReserveItem.

        Int64, The beginning time of bucket in unix timestamp  # noqa: E501

        :param start_time: The start_time of this ReserveItem.  # noqa: E501
        :type: str
        """
        if start_time is None:
            raise ValueError("Invalid value for `start_time`, must not be `None`")  # noqa: E501

        self._start_time = start_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ReserveItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReserveItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
