# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.31.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RunePoolWithdrawMetadata(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'affiliate_address': 'str',
        'affiliate_amount': 'str',
        'affiliate_basis_point': 'str',
        'basis_points': 'str',
        'units': 'str'
    }

    attribute_map = {
        'affiliate_address': 'affiliateAddress',
        'affiliate_amount': 'affiliateAmount',
        'affiliate_basis_point': 'affiliateBasisPoint',
        'basis_points': 'basisPoints',
        'units': 'units'
    }

    def __init__(self, affiliate_address=None, affiliate_amount=None, affiliate_basis_point=None, basis_points=None, units=None):  # noqa: E501
        """RunePoolWithdrawMetadata - a model defined in Swagger"""  # noqa: E501
        self._affiliate_address = None
        self._affiliate_amount = None
        self._affiliate_basis_point = None
        self._basis_points = None
        self._units = None
        self.discriminator = None
        self.affiliate_address = affiliate_address
        self.affiliate_amount = affiliate_amount
        self.affiliate_basis_point = affiliate_basis_point
        self.basis_points = basis_points
        self.units = units

    @property
    def affiliate_address(self):
        """Gets the affiliate_address of this RunePoolWithdrawMetadata.  # noqa: E501

        Transaction affiliate address  # noqa: E501

        :return: The affiliate_address of this RunePoolWithdrawMetadata.  # noqa: E501
        :rtype: str
        """
        return self._affiliate_address

    @affiliate_address.setter
    def affiliate_address(self, affiliate_address):
        """Sets the affiliate_address of this RunePoolWithdrawMetadata.

        Transaction affiliate address  # noqa: E501

        :param affiliate_address: The affiliate_address of this RunePoolWithdrawMetadata.  # noqa: E501
        :type: str
        """
        if affiliate_address is None:
            raise ValueError("Invalid value for `affiliate_address`, must not be `None`")  # noqa: E501

        self._affiliate_address = affiliate_address

    @property
    def affiliate_amount(self):
        """Gets the affiliate_amount of this RunePoolWithdrawMetadata.  # noqa: E501

        Int64, Transaction affiliate amount in rune  # noqa: E501

        :return: The affiliate_amount of this RunePoolWithdrawMetadata.  # noqa: E501
        :rtype: str
        """
        return self._affiliate_amount

    @affiliate_amount.setter
    def affiliate_amount(self, affiliate_amount):
        """Sets the affiliate_amount of this RunePoolWithdrawMetadata.

        Int64, Transaction affiliate amount in rune  # noqa: E501

        :param affiliate_amount: The affiliate_amount of this RunePoolWithdrawMetadata.  # noqa: E501
        :type: str
        """
        if affiliate_amount is None:
            raise ValueError("Invalid value for `affiliate_amount`, must not be `None`")  # noqa: E501

        self._affiliate_amount = affiliate_amount

    @property
    def affiliate_basis_point(self):
        """Gets the affiliate_basis_point of this RunePoolWithdrawMetadata.  # noqa: E501

        Transaction affiliate basis point  # noqa: E501

        :return: The affiliate_basis_point of this RunePoolWithdrawMetadata.  # noqa: E501
        :rtype: str
        """
        return self._affiliate_basis_point

    @affiliate_basis_point.setter
    def affiliate_basis_point(self, affiliate_basis_point):
        """Sets the affiliate_basis_point of this RunePoolWithdrawMetadata.

        Transaction affiliate basis point  # noqa: E501

        :param affiliate_basis_point: The affiliate_basis_point of this RunePoolWithdrawMetadata.  # noqa: E501
        :type: str
        """
        if affiliate_basis_point is None:
            raise ValueError("Invalid value for `affiliate_basis_point`, must not be `None`")  # noqa: E501

        self._affiliate_basis_point = affiliate_basis_point

    @property
    def basis_points(self):
        """Gets the basis_points of this RunePoolWithdrawMetadata.  # noqa: E501

        Int64 (Basis points, 0-10000, where 10000=100%), percentage of total ownership withdrawn   # noqa: E501

        :return: The basis_points of this RunePoolWithdrawMetadata.  # noqa: E501
        :rtype: str
        """
        return self._basis_points

    @basis_points.setter
    def basis_points(self, basis_points):
        """Sets the basis_points of this RunePoolWithdrawMetadata.

        Int64 (Basis points, 0-10000, where 10000=100%), percentage of total ownership withdrawn   # noqa: E501

        :param basis_points: The basis_points of this RunePoolWithdrawMetadata.  # noqa: E501
        :type: str
        """
        if basis_points is None:
            raise ValueError("Invalid value for `basis_points`, must not be `None`")  # noqa: E501

        self._basis_points = basis_points

    @property
    def units(self):
        """Gets the units of this RunePoolWithdrawMetadata.  # noqa: E501

        Int64, amount of units removed from the member as result of the withdrawal   # noqa: E501

        :return: The units of this RunePoolWithdrawMetadata.  # noqa: E501
        :rtype: str
        """
        return self._units

    @units.setter
    def units(self, units):
        """Sets the units of this RunePoolWithdrawMetadata.

        Int64, amount of units removed from the member as result of the withdrawal   # noqa: E501

        :param units: The units of this RunePoolWithdrawMetadata.  # noqa: E501
        :type: str
        """
        if units is None:
            raise ValueError("Invalid value for `units`, must not be `None`")  # noqa: E501

        self._units = units

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RunePoolWithdrawMetadata, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RunePoolWithdrawMetadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
