# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.31.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AffiliateHistoryItem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'count': 'str',
        'end_time': 'str',
        'start_time': 'str',
        'thornames': 'list[ItemThorname]',
        'volume': 'str',
        'volume_usd': 'str'
    }

    attribute_map = {
        'count': 'count',
        'end_time': 'endTime',
        'start_time': 'startTime',
        'thornames': 'thornames',
        'volume': 'volume',
        'volume_usd': 'volumeUSD'
    }

    def __init__(self, count=None, end_time=None, start_time=None, thornames=None, volume=None, volume_usd=None):  # noqa: E501
        """AffiliateHistoryItem - a model defined in Swagger"""  # noqa: E501
        self._count = None
        self._end_time = None
        self._start_time = None
        self._thornames = None
        self._volume = None
        self._volume_usd = None
        self.discriminator = None
        self.count = count
        self.end_time = end_time
        self.start_time = start_time
        self.thornames = thornames
        self.volume = volume
        self.volume_usd = volume_usd

    @property
    def count(self):
        """Gets the count of this AffiliateHistoryItem.  # noqa: E501

        Int64, The count of affiliates during the time interval   # noqa: E501

        :return: The count of this AffiliateHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this AffiliateHistoryItem.

        Int64, The count of affiliates during the time interval   # noqa: E501

        :param count: The count of this AffiliateHistoryItem.  # noqa: E501
        :type: str
        """
        if count is None:
            raise ValueError("Invalid value for `count`, must not be `None`")  # noqa: E501

        self._count = count

    @property
    def end_time(self):
        """Gets the end_time of this AffiliateHistoryItem.  # noqa: E501

        Int64, The end time of bucket in unix timestamp  # noqa: E501

        :return: The end_time of this AffiliateHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this AffiliateHistoryItem.

        Int64, The end time of bucket in unix timestamp  # noqa: E501

        :param end_time: The end_time of this AffiliateHistoryItem.  # noqa: E501
        :type: str
        """
        if end_time is None:
            raise ValueError("Invalid value for `end_time`, must not be `None`")  # noqa: E501

        self._end_time = end_time

    @property
    def start_time(self):
        """Gets the start_time of this AffiliateHistoryItem.  # noqa: E501

        Int64, The beginning time of bucket in unix timestamp  # noqa: E501

        :return: The start_time of this AffiliateHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this AffiliateHistoryItem.

        Int64, The beginning time of bucket in unix timestamp  # noqa: E501

        :param start_time: The start_time of this AffiliateHistoryItem.  # noqa: E501
        :type: str
        """
        if start_time is None:
            raise ValueError("Invalid value for `start_time`, must not be `None`")  # noqa: E501

        self._start_time = start_time

    @property
    def thornames(self):
        """Gets the thornames of this AffiliateHistoryItem.  # noqa: E501


        :return: The thornames of this AffiliateHistoryItem.  # noqa: E501
        :rtype: list[ItemThorname]
        """
        return self._thornames

    @thornames.setter
    def thornames(self, thornames):
        """Sets the thornames of this AffiliateHistoryItem.


        :param thornames: The thornames of this AffiliateHistoryItem.  # noqa: E501
        :type: list[ItemThorname]
        """
        if thornames is None:
            raise ValueError("Invalid value for `thornames`, must not be `None`")  # noqa: E501

        self._thornames = thornames

    @property
    def volume(self):
        """Gets the volume of this AffiliateHistoryItem.  # noqa: E501

        Int64(e8), The total volume of the affiliates detonated in RUNE   # noqa: E501

        :return: The volume of this AffiliateHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._volume

    @volume.setter
    def volume(self, volume):
        """Sets the volume of this AffiliateHistoryItem.

        Int64(e8), The total volume of the affiliates detonated in RUNE   # noqa: E501

        :param volume: The volume of this AffiliateHistoryItem.  # noqa: E501
        :type: str
        """
        if volume is None:
            raise ValueError("Invalid value for `volume`, must not be `None`")  # noqa: E501

        self._volume = volume

    @property
    def volume_usd(self):
        """Gets the volume_usd of this AffiliateHistoryItem.  # noqa: E501

        Int64(e2), The total volume of the affiliates denoted in USD price of the rune in each swap   # noqa: E501

        :return: The volume_usd of this AffiliateHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._volume_usd

    @volume_usd.setter
    def volume_usd(self, volume_usd):
        """Sets the volume_usd of this AffiliateHistoryItem.

        Int64(e2), The total volume of the affiliates denoted in USD price of the rune in each swap   # noqa: E501

        :param volume_usd: The volume_usd of this AffiliateHistoryItem.  # noqa: E501
        :type: str
        """
        if volume_usd is None:
            raise ValueError("Invalid value for `volume_usd`, must not be `None`")  # noqa: E501

        self._volume_usd = volume_usd

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AffiliateHistoryItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AffiliateHistoryItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
