# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.31.0
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ItemThorname(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'count': 'str',
        'thorname': 'str',
        'volume': 'str',
        'volume_usd': 'str'
    }

    attribute_map = {
        'count': 'count',
        'thorname': 'thorname',
        'volume': 'volume',
        'volume_usd': 'volumeUSD'
    }

    def __init__(self, count=None, thorname=None, volume=None, volume_usd=None):  # noqa: E501
        """ItemThorname - a model defined in Swagger"""  # noqa: E501
        self._count = None
        self._thorname = None
        self._volume = None
        self._volume_usd = None
        self.discriminator = None
        self.count = count
        self.thorname = thorname
        self.volume = volume
        self.volume_usd = volume_usd

    @property
    def count(self):
        """Gets the count of this ItemThorname.  # noqa: E501

        Int64, The count of affiliates with the same thorname during the time interval   # noqa: E501

        :return: The count of this ItemThorname.  # noqa: E501
        :rtype: str
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this ItemThorname.

        Int64, The count of affiliates with the same thorname during the time interval   # noqa: E501

        :param count: The count of this ItemThorname.  # noqa: E501
        :type: str
        """
        if count is None:
            raise ValueError("Invalid value for `count`, must not be `None`")  # noqa: E501

        self._count = count

    @property
    def thorname(self):
        """Gets the thorname of this ItemThorname.  # noqa: E501

        thorname of the affiliate  # noqa: E501

        :return: The thorname of this ItemThorname.  # noqa: E501
        :rtype: str
        """
        return self._thorname

    @thorname.setter
    def thorname(self, thorname):
        """Sets the thorname of this ItemThorname.

        thorname of the affiliate  # noqa: E501

        :param thorname: The thorname of this ItemThorname.  # noqa: E501
        :type: str
        """
        if thorname is None:
            raise ValueError("Invalid value for `thorname`, must not be `None`")  # noqa: E501

        self._thorname = thorname

    @property
    def volume(self):
        """Gets the volume of this ItemThorname.  # noqa: E501

        Int64(e8), The volume of affiliates with the same thorname detonated in RUNE   # noqa: E501

        :return: The volume of this ItemThorname.  # noqa: E501
        :rtype: str
        """
        return self._volume

    @volume.setter
    def volume(self, volume):
        """Sets the volume of this ItemThorname.

        Int64(e8), The volume of affiliates with the same thorname detonated in RUNE   # noqa: E501

        :param volume: The volume of this ItemThorname.  # noqa: E501
        :type: str
        """
        if volume is None:
            raise ValueError("Invalid value for `volume`, must not be `None`")  # noqa: E501

        self._volume = volume

    @property
    def volume_usd(self):
        """Gets the volume_usd of this ItemThorname.  # noqa: E501

        Int64(e2), The volume of affiliates with the same thorname denoted in USD price of the rune in each swap   # noqa: E501

        :return: The volume_usd of this ItemThorname.  # noqa: E501
        :rtype: str
        """
        return self._volume_usd

    @volume_usd.setter
    def volume_usd(self, volume_usd):
        """Sets the volume_usd of this ItemThorname.

        Int64(e2), The volume of affiliates with the same thorname denoted in USD price of the rune in each swap   # noqa: E501

        :param volume_usd: The volume_usd of this ItemThorname.  # noqa: E501
        :type: str
        """
        if volume_usd is None:
            raise ValueError("Invalid value for `volume_usd`, must not be `None`")  # noqa: E501

        self._volume_usd = volume_usd

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ItemThorname, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ItemThorname):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
